# Body

The document body. The body typically contains the full document contents except for headers, footers, and footnotes.

**Type:** object

## Properties

- **content** (array of [StructuralElement](structuralelement.md)): The contents of the body. The indexes for the body's content begin at zero.
